-- widget title=Assessment overview, row=5, col=0, size_x=8, size_y=3

## Assessment summary

- Readiness is based on # objects having one or more issues divided by total # of objects

- [Assessment Finding Index](https://github.com/databrickslabs/ucx/blob/main/docs/assessment.md#assessment-finding-index) provides a key to the items found in the "Assessment Summary" widget


[documentation](https://github.com/databrickslabs/ucx/blob/main/docs/assessment.md)
